@@ -35,10 +35,51 @@ varinlog = namedtuple('varinlog',
                       'log_counter_limit'])
 
 class lognflow:
-    """ lognflow logs your workflow
+    """ lognflow initialization
+        
+    The lognflow is an easy way to log your variables into a directory.
+    This directory is assumed to be local but it can be a map to a network
+    location. It will also size up files when they get too large.
+    It also can save np.arrays in npz format which is better than 
+    other formats.
+    
+    .. note::
+        One of the variables ``logs_root`` or ``log_dir`` must be given.
+        if ``log_dir`` is given, ``logs_root`` is disregarded.
+
+    :param logs_root: 
+        This is the root directory for all logs.
+        We will use the time.time() to create a log directory for each 
+        instance of the lognflow. 
+    :type logs_root: pathlib.Path
+    
+    :param log_dir: 
+        This is the final directory path for the log files. 
+    :type log_dir: pathlib.Path
+
+    :param print_text: 
+        If True, everything that is logged as text will be printed as well
+    :type print_text: bool
+    
+    :param main_log_name: 
+        main log file name, by default: 'main_log'
+    :type main_log_name: str
+            
+    :param log_flush_period:
+        The period between flushing the log files into HDD. By not
+        flushing, you can reduce network or HDD overhead.
+    :type log_flush_period: int
+            
+    :param log_flush_period_increase_rate:
+        we do not begin the timeout for the flush to be log_flush_period
+        because it can happen that a code finishes very fast. Such a 
+        code of course will flush everything when Python closes all
+        the files. We would like to flush at small intervals at first
+        and increase that timput over time. This is the rate. However,
+        when the log_flush_period reaches the given input, it will
+        not increase anymore.
+    :type log_flush_period_increase_rate: int
     
-    Indeed we need a simple log maker that works on local machine disk.
-    This is a minimalist approach to solve this problem. 
     """
     
     def __init__(self, 
@@ -48,52 +89,6 @@ class lognflow:
                  main_log_name = 'main_log',
                  log_flush_period = 60,
                  log_flush_period_increase_rate = 4):
-        """ lognflow initialization
-        
-        The lognflow is an easy way to log your variables into a directory.
-        This directory is assumed to be local but it can be a map to a network
-        location. It will also size up files when they get too large.
-        It also can save np.arrays in npz format which is better than 
-        other formats.
-        
-        .. note::
-            One of the variables ``logs_root`` or ``log_dir`` must be given.
-            if ``log_dir`` is given, ``logs_root`` is disregarded.
-
-        :param logs_root: 
-            This is the root directory for all logs.
-            We will use the time.time() to create a log directory for each 
-            instance of the lognflow. 
-        :type logs_root: pathlib.Path
-        
-        :param log_dir: 
-            This is the final directory path for the log files. 
-        :type log_dir: pathlib.Path
-
-        :param print_text: 
-            If True, everything that is logged as text will be printed as well
-        :type print_text: bool
-        
-        :param main_log_name: 
-            main log file name, by default: 'main_log'
-        :type main_log_name: str
-                
-        :param log_flush_period:
-            The period between flushing the log files into HDD. By not
-            flushing, you can reduce network or HDD overhead.
-        :type log_flush_period: int
-                
-        :param log_flush_period_increase_rate:
-            we do not begin the timeout for the flush to be log_flush_period
-            because it can happen that a code finishes very fast. Such a 
-            code of course will flush everything when Python closes all
-            the files. We would like to flush at small intervals at first
-            and increase that timput over time. This is the rate. However,
-            when the log_flush_period reaches the given input, it will
-            not increase anymore.
-        :type log_flush_period_increase_rate: int
-        
-        """
         self._init_time = time.time()
 
         if(log_dir is None):
@@ -883,7 +878,7 @@ class lognflow:
     
     def prepare_stack_of_images(self, 
                                 list_of_stacks, 
-                                nan_borders = True):
+                                nan_borders = np.nan):
         """Prepare the stack of images
             If you wish to use the log_canvas, chances are you have a list
             of stacks of images where one element, has many channels.
@@ -981,20 +976,23 @@ class lognflow:
                 ax1.set_xticklabels([])
                 ax1.set_yticklabels([])
                 data_canvas = list_of_stacks[stack_cnt][img_cnt].copy()
-                vmin = data_canvas.min()
-                vmax = data_canvas.max()
                 if(list_of_masks is not None):
                     mask = list_of_masks[stack_cnt]
                     if(mask is not None):
                         if(data_canvas.shape == mask.shape):
                             data_canvas[mask==0] = 0
-                            vmin = data_canvas[mask>0].min()
-                            vmax = data_canvas[mask>0].max()
+                            data_canvas_stat = data_canvas[mask>0]
                         elif(not canvas_mask_warning):
                             self.log_text(self.log_name,\
                                 'The mask shape is different from the canvas.' \
                                 + ' No mask will be applied.')
                             canvas_mask_warning = True
+                else:
+                    data_canvas_stat = data_canvas.copy()
+                data_canvas_stat = data_canvas_stat[np.isnan(data_canvas_stat) == 0]
+                data_canvas_stat = data_canvas_stat[np.isinf(data_canvas_stat) == 0]
+                vmin = data_canvas_stat.min()
+                vmax = data_canvas_stat.max()
                 im = ax1.imshow(data_canvas, 
                                 vmin = vmin, 
                                 vmax = vmax,
