@@ -8,7 +8,7 @@ class logviewer:
         Since lognflow makes lots of files and folders, maybe it is nice
         to have a logviewer that loads those information. In this module we
         provide a set of functions for a logged object that can load variables,
-        texts, file lists and .... simply, use it by:
+        texts, file lists and etc.. Use it simply by:
         
         .. highlight:: python
            :linenothreshold: 5
@@ -31,10 +31,8 @@ class logviewer:
     def get_text(self, log_name='main_log'):
         """ get text log files
             Given the log_name, this function returns the text therein.
-            
-            Parameters
-            ----------
-            log_name: str
+
+            :param log_name:
                 the log name. If not given then it is the main log.
         """
         flist = list(self.log_dir.glob(f'{log_name}*.txt'))
@@ -50,30 +48,45 @@ class logviewer:
             return txt
 
     def get_single(self, var_name, single_shot_index = -1, 
-                     suffix = '.np*', mat_file_field = None):
+                     suffix = '.np*'):
         """ get a single variable
             return the value of a saved variable.
-            
-            Parameters
-            ----------
-                var_name: str
-                    variable name
-                single_shot_index : integer index
-                    If there are many snapshots of a variable, this input can
-                    limit the returned to a set of indices.
-                suffix : str
-                    If there are different suffixes availble for a variable
-                    this input needs to be set. npy, npz, mat, and torch are
-                    supported.
-                mat_file_field : str
-                    when reading a MATLAB file, the field name is necessary.
+
+            :param var_name:
+                variable name
+            :param single_shot_index:
+                If there are many snapshots of a variable, this input can
+                limit the returned to a set of indices.
+            :param suffix:
+                If there are different suffixes availble for a variable
+                this input needs to be set. npy, npz, mat, and torch are
+                supported.
+                
+            .. note::
+                when reading a MATLAB file, the output is a dictionary.
         """
-        flist = list(self.log_dir.glob(f'{var_name}*{suffix}'))
+        suffix = suffix.strip('.')
+        assert single_shot_index == int(single_shot_index), \
+                    f'single_shot_index {single_shot_index} must be an integer'
+                    
+        if((self.log_dir / var_name).is_file()):
+            flist = [self.log_dir / var_name]
+        elif((self.log_dir / f'{var_name}.{suffix}').is_file()):
+            flist = [self.log_dir / f'{var_name}.{suffix}']
+        else:
+            flist = list(self.log_dir.glob(f'{var_name}*.{suffix}'))
+        
         if(len(flist) > 0):
             flist.sort()
             var_path = flist[single_shot_index]
-            if(not var_path.is_file()):
-                return
+        else:
+            var_dir = self.log_dir / var_name
+            if(var_dir.is_dir()):
+                flist = list(var_dir.glob('*.*'))
+                flist.sort()
+                var_path = flist[single_shot_index]
+                
+        if(var_path.is_file()):
             self.logger(f'Loading {var_path}')
             if(var_path.suffix == '.npz'):
                 buf = np.load(var_path)
@@ -82,38 +95,17 @@ class logviewer:
                 time_array = time_array[:n_logs]
                 data_array = buf['data_array']
                 data_array = data_array[:n_logs]
-                return(time_array, data_array)
+                return((time_array, data_array))
             elif(var_path.suffix == '.npy'):
                 return(np.load(var_path))
             elif(var_path.suffix == '.mat'):
-                if(mat_file_field is None):
-                    mat_file_field = var_path.name
-                try:
-                    return(loadmat(var_path)[mat_file_field])
-                except:
-                    self.logger(f'The firld name: {mat_file_field}, '\
-                            + f'could not be found in the mat file {var_path}')
+                return(loadmat(var_path))
             elif(var_path.suffix == '.torch'):      
                 from torch import load as torch_load 
                 return(torch_load(var_path))
         else:
-            var_dir = self.log_dir / var_name
-            if(var_dir.is_dir()):
-                flist = list(var_dir.glob('*.*'))
-                flist.sort()
-                assert single_shot_index == int(single_shot_index), \
-                    f'single_shot_index {single_shot_index} must be an integer'
-                var_path = flist[single_shot_index]
-                if(var_path.suffix == '.npy'):
-                    return np.load(var_path)
-                elif(var_path.suffix == '.mat'):
-                    if(mat_file_field is None):
-                        mat_file_field = var_path.name
-                    try:
-                        return(loadmat(var_path)[mat_file_field])
-                    except:
-                        self.logger(f'The firld name: {mat_file_field}, '\
-                            + f'could not be found in the mat file {var_path}')
+            self.logger(f'{var_name} not found.')
+            return
     
     def get_stack_of_files(self, 
         var_name = None, flist = [], 
@@ -124,18 +116,20 @@ class logviewer:
             This function gives the list of paths of all files in a directory
             for a single variable. 
 
-            Parameters
-            ----------
-                var_name : str
-                    The directory or variable name to look for the files
-                flist: list of Paths
-                    If data is returned, this flist input can limit the data
-                    requested to this list.
-                return_data : bool
+            :param var_name:
+                The directory or variable name to look for the files
+            :type var_name: str
+            
+            :param flist:
+                list of Paths, if data is returned, this flist input can limit 
+                the data requested to this list.
+            :type flist: list
+            
+            :param return_data: 
                     with flist you can limit the data that is returned.
                     Otherwise the data for all files in the directory will be
                     returned
-                return_flist : bool
+            :param return_flist
                     Maybe you are only intrested in the flist.
         """
         
@@ -191,12 +185,12 @@ class logviewer:
         
             It happens often in ML that there are two directories, A and B,
             and we are interested to get the flist in both that is common 
-            between them.
+            between them. returns a tuple of two lists of files.
             
-            Parameters
-            ----------
-            var_name_A and var_name_B:
-                directories A and B names.
+            :param var_name_A:
+                directory A name
+            :param var_name_B:
+                directory B name
         """
         flist_A = self.get_stack_of_files(
             var_name_A, return_data = False, return_flist = True)
@@ -229,10 +223,7 @@ class logviewer:
             This function changes all of the time stamps, sorted ascendingly,
             by indices.
             
-            Parameters
-            ----------
-            
-                var_name: str
+            :param var_name:
                 variable name
         """
         var_dir = self.log_dir / var_name
